@@ -18,6 +18,8 @@ sub ACTION_install {
 
   my $pkg = $self->notes('package');
 
+  warn "Package is [$pkg]";
+
   my $path = $INC{'AudioFile/Info.pm'};
 
   $path =~ s/Info.pm$/plugins.yaml/;
@@ -35,11 +37,11 @@ sub ACTION_install {
   my ($mp3, $ogg);
 
   for (qw(read write)) {
-    $mp3 += 50 if $config->{$pkg}{"${_}_mp3"};
+    ++$mp3 if $config->{$pkg}{"${_}_mp3"};
   }
 
   for (qw(read write)) {
-    $ogg +=50 if $config->{$pkg}{"${_}_ogg"};
+    ++$ogg if $config->{$pkg}{"${_}_ogg"};
   }
 
   # prefer non-perl implementations
@@ -50,14 +52,14 @@ sub ACTION_install {
 
   # if no default set and this plugin has a score, or if this plugin
   # score higher than the existing default, then set default
-  if ($mp3 and (not exists $config->{default}{mp3}
-     or $mp3 >= $config->{default}{mp3}{score})) {
+  if (! exists $config->{default}{mp3} and $mp3
+     or $mp3 and $mp3 >= $config->{default}{mp3}{score}) {
     $config->{default}{mp3} = { name => $pkg, score => $mp3 };
     warn "AudioFile::Info - Default mp3 handler is now $pkg\n";
   }
 
-  if ($ogg and (not exists $config->{default}{ogg}
-     or $ogg >= $config->{default}{ogg}{score})) {
+  if (! exists $config->{default}{ogg} and $ogg
+     or $ogg and $ogg >= $config->{default}{ogg}{score}) {
     $config->{default}{ogg} = { name => $pkg, score => $ogg };
     warn "AudioFile::Info - Default ogg handler is now $pkg\n";
   }
@@ -66,34 +68,3 @@ sub ACTION_install {
 }
 
 1;
-
-=head1 NAME
-
-AudioFile::Info::Build - Build utilities for AudioFile::Info.
-
-=head1 DESCRIPTION
-
-This is a module which is used as part of the build system for
-AudioFile::Info plugins.
-
-See L<AudioFile::Info> for more details.
-
-=head1 METHODS
-
-=head2 ACTION_install
-
-Overrides the ACTION_install method from Module::Build.
-
-=head1 AUTHOR
-
-Dave Cross, E<lt>dave@perlhacks.comE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2003 by Dave Cross
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=cut
-
