@@ -1,17 +1,3 @@
-=head1 NAME
-
-AudioFile::Info::Ogg::Vorbis::Header::PurePerl - Perl extension to get
-info from Ogg Vorbis files.
-
-=head1 DESCRIPTION
-
-Extracts data from an Ogg Vorbis file using the CPAN module
-Ogg::Vorbis::Header::PurePerl.
-
-See L<AudioFile::Info> for more details.
-
-=cut
-
 package AudioFile::Info::Ogg::Vorbis::Header::PurePerl;
 
 use 5.006;
@@ -21,14 +7,14 @@ use Carp;
 
 use Ogg::Vorbis::Header::PurePerl;
 
-our $VERSION = '1.5.5';
+our $VERSION = sprintf "%d.%02d", '$Revision: 1.2 $ ' =~ /(\d+)\.(\d+)/;
 
-my %data = (artist => 'ARTIST',
-            title  => 'TITLE',
-            album  => 'ALBUM',
-            track  => 'TRACKNUMBER',
-            year   => 'DATE',
-            genre  => 'GENRE');
+my %data = (artist => 'artist',
+            title  => 'title',
+            album  => 'album',
+            track  => 'tracknumber',
+            year   => 'date',
+            genre  => 'genre');
 
 sub new {
   my $class = shift;
@@ -54,22 +40,27 @@ sub AUTOLOAD {
 1;
 __END__
 
-=head1 METHODS
+=head1 NAME
 
-=head2 new
+AudioFile::Info::Ogg::Vorbis::Header::PurePerl - Perl extension to get
+info from Ogg Vorbis files.
 
-Creates a new object of class AudioFile::Info::MP3::ID3Lib. Usually called
-by AudioFile::Info::new.
+=head1 DESCRIPTION
+
+Extracts data from an Ogg Vorbis file using the CPAN module
+Ogg::Vorbis::Header::PurePerl.
+
+See L<AudioFile::Info> for more details.
 
 =head1 AUTHOR
 
-Dave Cross, E<lt>dave@perlhacks.comE<gt>
+Dave Cross, E<lt>dave@dave.org.ukE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2003 by Dave Cross
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
